@@ -19,8 +19,8 @@ class Default(objects.Object):
 			data_path = f"{self.path}/{group}"
 		else:
 			data_path = f"{self.path}/{group}/"+id.replace("/", "\\")
-			base = Formats.FilePath(data_path).base()
-			if not os.path.exists(base): os.system(f"mkdir {data_path}")
+		base = Formats.FilePath(data_path).base()
+		if not os.path.exists(base): os.system(f"mkdir -p {base}")
 		if format in [str, "str", "string", int, float, "int", "integer", "float", "double"]:
 			Files.save(data_path, str(data), format="str")
 		elif format in [dict, list, "dict", "dictionary", "list", "array", "json"]:
@@ -32,8 +32,8 @@ class Default(objects.Object):
 			data_path = f"{self.path}/{group}"
 		else:
 			data_path = f"{self.path}/{group}/"+id.replace("/", "\\")
-			base = Formats.FilePath(data_path).base()
-			if not os.path.exists(base): os.system(f"mkdir {data_path}")
+		base = Formats.FilePath(data_path).base()
+		if not os.path.exists(base): os.system(f"mkdir -p {base}")
 		def load():
 			if format in [str, "str", "string"]:
 				return Files.load(data_path, format="str")
@@ -82,7 +82,10 @@ class WebServer(objects.Thread):
 			"value":value,
 			"token":self.token(),
 		})
-		response = requests.get(f'http://{self.host}:{self.port}/set?{encoded}')
+		try:
+			response = requests.get(f'http://{self.host}:{self.port}/set?{encoded}')
+		except Exception as e:
+			return r3sponse.error_response(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
 			response = response.json()
 		except:
@@ -93,7 +96,10 @@ class WebServer(objects.Thread):
 			"key":key,
 			"token":self.token(),
 		})
-		response = requests.get(f'http://{self.host}:{self.port}/get?{encoded}')
+		try:
+			response = requests.get(f'http://{self.host}:{self.port}/get?{encoded}')
+		except Exception as e:
+			return r3sponse.error_response(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
 			response = response.json()
 		except:
@@ -101,6 +107,8 @@ class WebServer(objects.Thread):
 		return r3sponse.ResponseObject(response)
 	def app(self):
 		app = flask.Flask(__name__)
+		log = logging.getLogger('werkzeug')
+		log.disabled = True
 		@app.route('/get')
 		def get():
 			token = request.args.get('token')
@@ -151,12 +159,11 @@ class WebServer(objects.Thread):
 		encoded = urllib.parse.urlencode({
 			"token":self.token(),
 		})
-		response = requests.get(f'http://{self.host}:{self.port}/active?{encoded}')
-		#try:
-		response = response.json()
-		#except:
-		#	return False
-		return True
+		try:
+			requests.get(f'http://{self.host}:{self.port}/active?{encoded}')
+			return True
+		except requests.exceptions.ConnectionError:
+			return False
 	def run(self):
 		self.__cache__.set(group=self.id, id="daemon", data="*running*")
 		self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
